#include "Board.h"

AT91PS_PMC pPMC   = AT91C_BASE_PMC;

void InitFrec(void)
{
	// Set Flash Waite state - Flash Memory Controler
	// if MCK = 47923200 I have 50 Cycle for 1 usecond
	AT91C_BASE_MC->MC_FMR = ((AT91C_MC_FMCN)&(48 <<16)) | AT91C_MC_FWS_1FWS ;

	// Watchdog Disable
	AT91C_BASE_WDTC->WDTC_WDMR= AT91C_WDTC_WDDIS;

	// Set MCK at 47 923 200
	// 1 Enabling the Main Oscillator:
	// SCK = 1/32768 = 30.51 uSecond
	// Start up time = 8 * 6 / SCK = 56 * 30.51 = 1,46484375 ms
	pPMC->PMC_MOR = (( AT91C_CKGR_OSCOUNT & (0x06 <<8) | AT91C_CKGR_MOSCEN ));

	// Wait the startup time
	while(!(pPMC->PMC_SR & AT91C_PMC_MOSCS));

	// 2 Checking the Main Oscillator Frequency (Optional)
	// 3 Setting PLL and divider:
	// - div by 5 Fin = 3,6864 =(18,432 / 5)
	// - Mul 25+1: Fout =	95,8464 =(3,6864 *26)
	// for 96 MHz the erroe is 0.16%
	// Field out NOT USED = 0
	// PLLCOUNT pll startup time estimate at : 0.844 ms
	// PLLCOUNT 28 = 0.000844 /(1/32768)
	pPMC->PMC_PLLR = ((AT91C_CKGR_DIV & 0x05) | (AT91C_CKGR_PLLCOUNT & (28<<8)) | (AT91C_CKGR_MUL & (25<<16)));

	// Wait the startup time
	while(!(pPMC->PMC_SR & AT91C_PMC_LOCK));
	while(!(pPMC->PMC_SR & AT91C_PMC_MCKRDY));

	// 4. Selection of Master Clock and Processor Clock
	// select the PLL clock divided by 2
	pPMC->PMC_MCKR =  AT91C_PMC_PRES_CLK_2 ;
	while(!(pPMC->PMC_SR & AT91C_PMC_MCKRDY));

	pPMC->PMC_MCKR |= AT91C_PMC_CSS_PLL_CLK  ;
	while(!(pPMC->PMC_SR & AT91C_PMC_MCKRDY));
}

int main(void)
{
	InitFrec();

	int iCount = 0;
	bool boLedState = false;
	// First, enable the clock of the PIO
	AT91F_PMC_EnablePeriphClock(AT91C_BASE_PMC, 1 << AT91C_ID_PIOB);

	// then configure the PIO Lines corresponding to LED to be outputs. No
	// need to set these pins to be driven by the PIO because it is GPIO pins only.
	AT91F_PIO_CfgOutput(AT91C_BASE_PIOB, LED_MASK);

	// Set the LCD Back LED.
	AT91F_PIO_SetOutput(AT91C_BASE_PIOB, LED_MASK);
	boLedState = true;

	// Loop forever
	while(1)
	{
		for(iCount = 0; iCount < 0xFFFF; iCount++);
		for(iCount = 0; iCount < 0xFFFF; iCount++);
		for(iCount = 0; iCount < 0xFFFF; iCount++);
		for(iCount = 0; iCount < 0xFFFF; iCount++);
		for(iCount = 0; iCount < 0xFFFF; iCount++);

		if(boLedState)
		{
			AT91F_PIO_ClearOutput(AT91C_BASE_PIOB, LED_MASK);
			boLedState = false;
		}
		else
		{
			AT91F_PIO_SetOutput(AT91C_BASE_PIOB, LED_MASK);
			boLedState = true;
		}
	}// End while(1)
	return 0;
}// End int main(void)
